USE ChangeTracking
GO


-- Variables for start, end version
DECLARE @CTVer BIGINT						-- Starting point
	, @CTVerEnd BIGINT						-- Ending point
	, @TableName VARCHAR(50) = 'dbo.Employees'

-- Get the starting version number from version marker table
SELECT @CTVer = ChangeTrackingVersion 
FROM etl.[ChangeTrackingETLVersion]
WHERE TableName = @TableName


-- Get the ending point using the version number from change tracking
SELECT @CTVerEnd = CHANGE_TRACKING_CURRENT_VERSION()



/*
	ETL start
*/

-- This is your source query for ETL
SELECT e.* 
	, ct.*
FROM CHANGETABLE(CHANGES dbo.Employees, @CTVer) ct
LEFT JOIN dbo.Employees e
	ON ct.EmployeeID = e.EmployeeID 
WHERE ct.SYS_CHANGE_VERSION <= @CTVerEnd
ORDER BY ct.SYS_CHANGE_OPERATION

/*
	ETL end
*/

-- Lastly, update the change tracking marker table
UPDATE etl.[ChangeTrackingETLVersion]
SET ChangeTrackingVersion = @CTVerEnd
WHERE TableName = @TableName
