USE ChangeTracking
GO

-- Change tracking variables
DECLARE @CTVer BIGINT
DECLARE @CTVerEnd BIGINT = CHANGE_TRACKING_CURRENT_VERSION()

-- Get last load 
SELECT @CTVer = ChangeTrackingVersion 
FROM etl.[ChangeTrackingETLVersion]
WHERE TableName = 'dbo.Employees'

-- Use consistent date
DECLARE @TheDate DATETIME = GETDATE();

-- Merge
MERGE dw.DimEmp AS target
USING (
	-- Use the CT query as the source
	SELECT e.* 
	FROM CHANGETABLE(CHANGES dbo.Employees, @CTVer) ct
	LEFT JOIN dbo.Employees e
		ON ct.EmployeeID = e.EmployeeID 
	WHERE ct.SYS_CHANGE_VERSION <= @CTVerEnd
	AND ct.SYS_CHANGE_OPERATION IN ('I', 'U')
	
) AS source
	ON source.EmployeeID = target.EmpID
WHEN MATCHED AND NOT (
	TARGET.FirstName = SOURCE.FirstName
	AND TARGET.LastName = SOURCE.LastName
	AND COALESCE(TARGET.MiddleName, '') = COALESCE(SOURCE.MiddleName, '')
	AND TARGET.ACTIVE = SOURCE.Active
)

THEN UPDATE
SET FirstName = SOURCE.FirstName
	, LastName = SOURCE.LastName
	, MiddleName = SOURCE.MiddleName
	, ACTIVE = SOURCE.ACTIVE
   
WHEN NOT MATCHED
THEN INSERT (EmpID
	, FirstName
	, MiddleName
	, LastName
	, Active
	, UpdatedDate
)
VALUES (SOURCE.EmployeeID
	, SOURCE.FirstName
	, SOURCE.MiddleName
	, SOURCE.LastName
	, COALESCE(SOURCE.Active, 0)
	, @TheDate
);


-- Update the load tracking table with the endpoint version of this load
UPDATE etl.[ChangeTrackingETLVersion]
SET ChangeTrackingVersion = @CTVerEnd
WHERE TableName = 'dbo.Employees'
