USE [TemporalSales]
GO

/* Drop */
IF 0 < (SELECT temporal_type FROM sys.tables WHERE OBJECT_ID = OBJECT_ID('[dbo].[Customers]'))
ALTER TABLE [dbo].[Customers] SET ( SYSTEM_VERSIONING = OFF  )
GO

IF (SELECT OBJECT_ID('dbo.Customers')) IS NOT NULL 
	DROP TABLE [dbo].[Customers]
IF (SELECT OBJECT_ID('dbo.CustomersHistory')) IS NOT NULL 
	DROP TABLE [dbo].[CustomersHistory]
GO


/* Create base table */
CREATE TABLE [dbo].[Customers](
	[CustomerKey] INT NOT NULL IDENTITY(1,1),
	[CustomerID] INT NOT NULL,
	[CustomerName] VARCHAR(100) NOT NULL,
	[CustomerCategory] VARCHAR(50) NULL,
	[PrimaryContactPersonID] INT NOT NULL,
	[PostalCityID] INT NOT NULL,
	[CreditLimit] DECIMAL(18, 2) NULL,
	[AccountOpenedDate] DATE NOT NULL,
	[StandardDiscountPercentage] DECIMAL(18, 3) NOT NULL,
	[IsStatementSent] BIT NOT NULL,
	[IsOnCreditHold] BIT NOT NULL,
	[PaymentDays] INT NOT NULL,
	[PhoneNumber] VARCHAR(20) NOT NULL,
	[FaxNumber] VARCHAR(20) NOT NULL,
	[WebsiteURL] VARCHAR(256) NOT NULL,
	[Address] VARCHAR(60) NOT NULL,
	[Address2] VARCHAR(60) NULL,
	[PostalCode] VARCHAR(10) NOT NULL,
	CONSTRAINT PK_Customers PRIMARY KEY (CustomerKey)
)

GO




INSERT dbo.Customers
(
    CustomerID,
    CustomerName,
    CustomerCategory,
    PrimaryContactPersonID,
    PostalCityID,
    CreditLimit,
    AccountOpenedDate,
    StandardDiscountPercentage,
    IsStatementSent,
    IsOnCreditHold,
    PaymentDays,
    PhoneNumber,
    FaxNumber,
    WebsiteURL,
    Address,
    Address2,
    PostalCode
	--, ValidFrom
	--, ValidTo
)
SELECT CustomerID,
       CustomerName,
       cc.CustomerCategoryName [CustomerCategory],
       PrimaryContactPersonID,
       PostalCityID,
       CreditLimit,
       AccountOpenedDate,
       StandardDiscountPercentage,
       IsStatementSent,
       IsOnCreditHold,
       PaymentDays,
       PhoneNumber,
       FaxNumber,
       WebsiteURL,
       DeliveryAddressLine1 [Address],
       DeliveryAddressLine2 [Address2],
       DeliveryPostalCode [PostalCode]
	   --, '1/1/1900'							-- Prime the ValidFrom field for beginning-of-time value
	   --, '9999-12-31 23:59:59.9999999'		-- Must set to max DATETIME2 value in prep for temporal table
FROM WideWorldImporters.Sales.Customers c
LEFT JOIN WideWorldImporters.Sales.CustomerCategories cc
	ON c.CustomerCategoryID = cc.CustomerCategoryID

