USE TemporalSales
GO


/****************************************************************************
	Add a new column. For a little extra fun, give it a default value and 
	set it to NOT NULL.
****************************************************************************/
ALTER TABLE dbo.Customers
ADD FavoriteColor VARCHAR(50) NOT NULL DEFAULT 'Blue'
GO





/****************************************************************************
		Show base and history table after the new column is added.
****************************************************************************/
SELECT * FROM dbo.Customers
SELECT * FROM dbo.CustomersHistory






/****************************************************************************
							Remove this new column
****************************************************************************/

-- First, remove the default
DECLARE @sql NVARCHAR(200)
SELECT @sql = N'ALTER TABLE [dbo].[Customers] DROP CONSTRAINT ' + o.name
FROM sys.objects o
INNER JOIN sys.columns c
	ON c.default_object_id = o.object_id
WHERE c.object_id = OBJECT_ID('[dbo].[Customers]')
AND c.name = 'FavoriteColor'

EXEC sp_executesql @sql

-- Now drop the column
ALTER TABLE dbo.Customers
DROP COLUMN FavoriteColor





/****************************************************************************
		Show base and history table after the removal of the new column.
****************************************************************************/
SELECT * FROM dbo.Customers
SELECT * FROM dbo.CustomersHistory





/****************************************************************************
		Try to add a column directly to the history table.
****************************************************************************/

ALTER TABLE dbo.CustomersHistory
ADD ShoeSize INT






/****************************************************************************
		Try to add an index directly to the history table.
****************************************************************************/

-- Will this work?
CREATE INDEX IX_CustomersHistory_FavColor
ON dbo.CustomersHistory (PostalCityID)

-- What about a unique index?
CREATE UNIQUE INDEX IX_CustomersHistory_xx
ON dbo.CustomersHistory (CustomerID, ValidFrom, ValidTo)




/****************************************************************************
		Add an index to the base table. Any changes on the history table?
****************************************************************************/

CREATE INDEX IX_Customers_CustName
ON dbo.Customers (CustomerName)
